@@ -8,32 +8,32 @@ NULL
 #' @param mean_climate_prec  a matrix containing monthly mean daily precipitation for the considered station. If it is \code{NULL}, it is calculated. See input of \code{\link{is.monthly.climate}}
 #' @param year_max start year of the recorded (calibration) period 
 #' @param year_min end year of the recorded (calibration) period
-#' @param leap logical variables. If it is \code{TRUE} (default), leap years are considered
+#' @param leap logical variables. If it is \code{TRUE} (default)(recommended), leap years are considered, otherwise all years have 365 days
 #' @param nmonth number of months in one year (default is 12)
 #' @param verbose logical variable
-#' @param cpf see \code{\link{normalizeGaussian_severalstations_prec}}
-#' @param sample,extremes,qnull,valmin see \code{\link{normalizeGaussian_severalstations_prec}}
-#' @param step see \code{\link{normalizeGaussian_severalstations_prec}}. Default is 0.
+#' @param cpf see \code{\link{normalizeGaussian_severalstations}}
+#' @param sample,extremes,qnull,valmin see \code{\link{normalizeGaussian_severalstations}}
+#' @param step see \code{\link{normalizeGaussian_severalstations}}. Default is 0.
 #' @param p,type,lag.max,ic,activateVARselect see respective input parameter on \code{\link{getVARmodel}}
 #' @param year_max_sim last year of the simulation period. Default is equal to \code{year_max} 
-#' @param year_min_sim fist year of the simulation period. Default is equal to \code{year_min}
+#' @param year_min_sim first year of the simulation period. Default is equal to \code{year_min}
 #' @param mean_climate_prec_sim a matrix containing monthly mean daily precipitation for the simulation period. If is \code{NULL} (Default), it is set equal to \code{mean_climate_prec}. 
 #' @param n_GPCA_iteration number of iteration of Gaussianization process for data. Default is 0 (no Gaussianization) 
-#' @param n_GPCA_iteration_residuals number of iteration of Gaussianization process for data. Default is 0 (no Gaussianization)
-#' @param exogen matrix containing the (normalized or not) exogenous variables (predictors) for the recorded (calibration) period. 
-#' @param exogen_sim  matrix containing the (normalized or not) exogenous variables (predictors) for the simulation period. Default is \code{exogen}
+#' @param n_GPCA_iteration_residuals number of iteration of Gaussianization process for VAR residuals. Default is 0 (no Gaussianization)
+#' @param exogen data frame or matrix containing the (normalized or not) exogenous variables (predictors) for the recorded (calibration) period. 
+#' @param exogen_sim  data frame or matrix containing the (normalized or not) exogenous variables (predictors) for the simulation period. Default is \code{NULL}. It is \code{NULL}, it is replaced with \code{exogen} within the function.
 #' @param is_exogen_gaussian logical value. If \code{TRUE}, \code{exogen_sim} and \code{exogen} are given as already normalized variables, otherwhise they are not normalized. Default is \code{FALSE}
 #' @param onlygeneration logical value. If \code{TRUE} the VAR model \code{varmodel} is given as input and only random generation is done, otherwise (default) is calculated from measured data 
-#' @param varmodel the VAR model as a \code{varest} object. If \code{NULL}, it is  given as input and only random generation is done, otherwise (default) is calculated from measured data 
+#' @param varmodel the comprehensinve VAR model as a \code{\link{varest2}} S4 object or a \code{NULL} object. If \code{NULL} (default), the comprehensinve VAR is estimated from measured data within the function, otherwise it is given as input and only random generation is done.
 #' @param type_quantile see \code{type} on \code{\link{quantile}}
-#' @param option_temp integer value. If 0 (default), exogenous variables (\code{exogen} and \code{exogen_sim} ) are not considered, if 1 exogenous variables are considered.  
+#### @param option_temp integer value. If 0 (default), exogenous variables (\code{exogen} and \code{exogen_sim} ) are not considered, if 1 exogenous variables are considered.  
 #' @param exogen_all data frame containing exogenous variable formatted like \code{prec_all}. Default is \code{NULL}. 
 #' It is alternative to \code{exogen} and if it not \code{NULL},\code{is_exogen_gaussian} is automatically set \code{FALSE}	
 #' @param exogen_all_col vector of considered  columns of \code{exogen_all}. Default is \code{station}.
 #' @param no_spline logical value. See \code{\link{splineInterpolateMonthlytoDailyforSeveralYears}}. Default is \code{TRUE}.
 #' @param nscenario number of possible generated scenarios for daily maximum and minimum temperature
-#' @param seed seed for stochastic random generation see \code{\link{set.seed}}
-#'   
+#' @param seed seed for stochastic random generation see \code{\link{set.seed}}.
+#' @param noise stochastic noise to add for variabile generation. Default is \code{NULL}. See \code{\link{newVARmultieventRealization}}. Not used in case that \code{nscenario>1}.
 #' 
 #' 
 #' 
@@ -60,7 +60,7 @@ NULL
 #' @return  A list of the following variables: 
 #' 
 #' 
-#' \code{prec_mes}        matrix contained measured daily precipitation
+#' \code{prec_mes}        matrix containing measured daily precipitation (the data is copied by the measured data given as input for the period and the station considered for \code{varmodel} estimation)
 #' 
 #' \code{prec_spline}      matrix containing climatic "spline-interpolated" daily preciptation from \code{mean_climate_prec}
 #' 
@@ -72,9 +72,9 @@ NULL
 #' 
 #' \code{data_prec_gen}            matrix containing normalized generated precipitation variable
 #' 
-#' \code{mean_climate_prec}        matrix containing monthly mean daily precipitation (historical scenario)
+#' \code{mean_climate_prec}        matrix containing monthly means of daily precipitation (historical scenario)
 #' 
-#' \code{mean_climate_prec_sim}    matrix containing monthly mean daily precipitation (predicted/simulated scenario)
+#' \code{mean_climate_prec_sim}    matrix containing monthly means of daily precipitation (predicted/simulated scenario)
 #' 
 #' \code{var}                 a varest object containing the used VAR model
 #' 
@@ -83,55 +83,51 @@ NULL
 #' 
 #' 
 
-#' @examples data(trentino)
-#'  
+#' @examples 
 #' 
-#' rm(list=ls())
-#' set.seed(1222)
-#' library(RMAWGEN)
 #' data(trentino)
-
+#' set.seed(1222) # set the seed for random generations!
 #'year_max <- 1990
 #'year_min <- 1961
 #'year_max_sim <- 1982
 #'year_min_sim <- 1981
-#origin <- "1961-1-1"
 #'
 #'n_GPCA_iter <- 2
 #' p <- 1
 #'nscenario=1
-#'station <- c("T0090","T0083") #,"T0099","T0001") 
-#
-#'generation00 <- ComprehensivePrecipitationGenerator(station=station,prec_all=PRECIPITATION,year_min=year_min,year_max=year_max,year_min_sim=year_min_sim,year_max_sim=year_max_sim,p=p,n_GPCA_iteration=n_GPCA_iter,n_GPCA_iteration_residuals=0,sample="monthly",nscenario=nscenario,no_spline=FALSE)
-
+#'station <- c("T0090","T0083")  
+#' ## Not Run: the call to ComprehensivePrecipitationGenerator may elapse too long time (more than 5 eseconds) and is not executed  by CRAN check.  
+#' ## Please uncomment the following line to run the example on your own PC. 
+#' # generation00 <- ComprehensivePrecipitationGenerator(station=station,prec_all=PRECIPITATION,year_min=year_min,year_max=year_max,year_min_sim=year_min_sim,year_max_sim=year_max_sim,p=p,n_GPCA_iteration=n_GPCA_iter,n_GPCA_iteration_residuals=0,sample="monthly",nscenario=nscenario,no_spline=TRUE)
+#' 
 ## 
-## #' 
-## #' 
-## #' 
-## #' year_max <- 1990
-## #'  year_min <- 1961
-## #' 
-## #' year_min_sim <- 1982
-## #' year_max_sim <- 1983
-## #' 
-## # origin <- "1961-1-1"
-## #' n_GPCA_iter <- 10
-## #' n_GPCA_iteration_residuals <- 10
-## #' 	vstation <- c("B2440","B6130","B8570","B9100","LAVIO","POLSA","SMICH","T0001",
-## #'  "T0010","T0014","T0018","T0032","T0064","T0083","T0090","T0092","T0094","T0099",
-## #'  "T0102","T0110","T0129","T0139","T0147","T0149","T0152","T0157","T0168","T0179","T0189","T0193","T0204","T0210","T0211","T0327","T0367","T0373")		
-## #' 	generation00 <-ComprehensiveTemperatureGenerator(station=vstation[14:15],Tx_all=TEMPERATURE_MAX,Tn_all=TEMPERATURE_MIN,year_min=year_min,year_max=year_max,p=1,n_GPCA_iteration=n_GPCA_iter,n_GPCA_iteration_residuals=n_GPCA_iteration_residuals,sample="monthly",year_min_sim=year_min_sim,year_max_sim=year_max_sim)
+## # by CRAN 
+## # 
+## # 
+##  year_max <- 1990
+## #  year_min <- 1961
+## # 
+## # year_min_sim <- 1982
+## # year_max_sim <- 1983
+## # 
+## #origin <- "1961-1-1"
+## # n_GPCA_iter <- 5
+## # n_GPCA_iteration_residuals <- 5
+## # 	vstation <- c("B2440","B6130","B8570","B9100","LAVIO","POLSA","SMICH","T0001",
+## #  "T0010","T0014","T0018","T0032","T0064","T0083","T0090","T0092","T0094","T0099",
+## #  "T0102","T0110","T0129","T0139","T0147","T0149","T0152","T0157","T0168","T0179","T0189","T0193","T0204","T0210","T0211","T0327","T0367","T0373")		
+## # 	generation00 <-ComprehensiveTemperatureGenerator(station=vstation[14:15],Tx_all=TEMPERATURE_MAX,Tn_all=TEMPERATURE_MIN,year_min=year_min,year_max=year_max,p=1,n_GPCA_iteration=n_GPCA_iter,n_GPCA_iteration_residuals=n_GPCA_iteration_residuals,sample="monthly",year_min_sim=year_min_sim,year_max_sim=year_max_sim)
 
 ## # 	str(generation00)
 ## #	print(generation00$var)
-## #' 
-## #' 
-## #' 
-## #' 
-## #' 
-## #' 
-## #' 
-## #' 
+## # 
+## # 
+## # 
+## # 
+## # 
+## # 
+## # 
+## # 
 
 ComprehensivePrecipitationGenerator <-
 function(
@@ -172,10 +168,11 @@ function(
 		exogen_all_col=station,
 		
 		
-		option_temp=0,
+	###	option_temp=0,
 		no_spline=FALSE,
 		nscenario=1,
-		seed=NULL
+		seed=NULL,
+		noise=NULL
 
 ) {
 	
@@ -229,7 +226,8 @@ function(
 		var <- varmodel		
 	}
 				
-				
+	# THIS LINE IS TEMPORARY AND ONLY FOR TESTING
+	if (!is.null(noise)) {if (noise=="residuals") noise <- residuals(var) }			
 				
 	if (is.null(mean_climate_prec_sim)) mean_climate_prec_sim <- mean_climate_prec
 	nyear_sim <- year_max_sim-year_min_sim+1
@@ -251,7 +249,7 @@ function(
 
 	if (!is.null(seed))	set.seed(seed)
 	
-	data_prec_gen <- newVARmultieventRealization(var,exogen=exogen_sim,nrealization=nrow(prec_spline_sim2),extremes=extremes,type=type_quantile) 
+	data_prec_gen <- newVARmultieventRealization(var,exogen=exogen_sim,nrealization=nrow(prec_spline_sim2),extremes=extremes,type=type_quantile,noise=noise) 
 #	data_prec_gen <- newVARmultieventRealization(var,exogen=exogen_sim,nrealization=nyear_sim,extremes=extremes,type=type_quantile) 
 	precrows <- 1:(min(c(nrow(prec_mes),nrow(prec_spline),nrow(prec_spline_sim))))
 	
